#
# Makefile for the petrol example
#
GOROOT=..
ETCDIR=../etc

CPPFLAGS=-DLEXDEBUG=1 -DYYDEBUG=1 -I$(ETCDIR)

SRCMO=	Absyn.mo FCEmit.mo FCode.mo Flatten.mo Main.mo Static.mo TCode.mo Types.mo
SRCC=	$(SRCMO:.mo=.c)
SRCH=	$(SRCMO:.mo=.h)
SRCO=	$(SRCMO:.mo=.o)

EXTRAO=	lexer.o Parser.o parsutil.o yacclib.o
EXTRAC=	Parser.c Parser.h y.tab.c y.tab.h
EXTRARM=y.output ccall1.o ccall2.o
BINARIES=petrol benchexe petrol.exe benchexe.exe
CLEAN=	$(SRCO) $(EXTRAO) $(EXTRARM) $(BINARIES) $(SRCC) $(SRCH) $(EXTRAC) *~ big big.exe big.c
ccall.c=$(ETCDIR)/ccall.c
yacclib.h=$(ETCDIR)/yacclib.h
yacclib.c=$(ETCDIR)/yacclib.c

ALMOSTPETROL=	$(SRCO) $(EXTRAO)

# default target
petrol:	$(ALMOSTPETROL) ccall1.o
	$(LINK.rml) -o petrol $(ALMOSTPETROL) ccall1.o

benchexe:	$(ALMOSTPETROL) ccall2.o
	$(LINK.rml) -o benchexe $(ALMOSTPETROL) ccall2.o

benchrun:	benchexe
	$(RUN) ./benchexe -bench testd/big.d
benchrun10:	benchexe
	for i in 0 1 2 3 4 5 6 7 8 9; do $(RUN) ./benchexe -bench testd/big.d; done

csources:	$(SRCC) $(EXTRAC)

ccall1.o:	$(ccall.c)
	$(COMPILE.rml) -UBENCH -o ccall1.o $(ccall.c)

ccall2.o:	$(ccall.c)
	$(COMPILE.rml) -DBENCH -o ccall2.o $(ccall.c)

lexer.o:	$(yacclib.h) parsutil.h Parser.h lexer.h
Parser.o:	Parser.c $(yacclib.h) parsutil.h lexer.h
parsutil.o:	$(yacclib.h) Absyn.h parsutil.h

yacclib.o:	$(yacclib.c) $(yacclib.h)
	$(COMPILE.rml) $(yacclib.c)

y.tab.c y.tab.h:	Parser.y
	$(YACC) -d Parser.y
	$(GOROOT)/etc/fixyacc < y.tab.c > y-tab-c
	mv y-tab-c y.tab.c

Parser.c:	y.tab.c
	$(GOROOT)/etc/cp-if-change y.tab.c Parser.c

Parser.h:	y.tab.h
	$(GOROOT)/etc/cp-if-change y.tab.h Parser.h

clean-binaries:
	rm -f $(BINARIES)
clean-objects:
	rm -f $(SRCO) $(EXTRAO) ccall1.o ccall2.o
clean-csources:
	rm -f $(SRCC) $(SRCH) $(EXTRAC)

distclean:	realclean clean-configure

realclean:	clean-csources clean

# running the program
run: petrol
	./petrol testd/big.d > big.c
	gcc -o big big.c
	./big

include $(GOROOT)/etc/client.mk
